@@ -8,24 +8,21 @@ use POE::Component::SmokeBox::Job;
 use POE::Component::SmokeBox::Result;
 use vars qw($VERSION);
 
-$VERSION = '0.43_01';
+$VERSION = '0.02';
 
 sub spawn {
   my $package = shift;
   my %params = @_;
   $params{lc $_} = delete $params{$_} for keys %params;
   my $options = delete $params{'options'};
-  $params{'delay'} = 0 unless exists $params{'delay'};
   my $self = bless \%params, $package;
   $self->{session_id} = POE::Session->create(
 	object_states => [
 	   $self => { 
-		shutdown      => '_shutdown',
-		add_smoker    => '_add_smoker',
-		del_smoker    => '_del_smoker',
-		submit        => '_submit',
-		register_ui   => '_reg_ui',
-		unregister_ui => '_unreg_ui',
+		shutdown   => '_shutdown',
+		add_smoker => '_add_smoker',
+		del_smoker => '_del_smoker',
+		submit     => '_submit',
 	   },
 	   $self => [qw(_start)],
 	],
@@ -43,20 +40,6 @@ sub multiplicity {
   return $_[0]->{multiplicity};
 }
 
-sub delay {
-  if ( defined $_[1] ) {
-    # verify it's an int
-    if ( $_[1] !~ /^\d+$/ ) {
-      return;
-    } else {
-      $_[0]->{delay} = $_[1];
-      return $_[1];
-    }
-  } else {
-    return $_[0]->{delay};
-  }
-}
-
 sub queues {
   return map { $_->{queue} } @{ $_[0]->{queues} };
 }
@@ -114,9 +97,7 @@ sub _add_smoker {
   # If multiplicity start a job queue for each smoker object.
   if ( $self->{multiplicity} or scalar @{ $self->{queues} } == 0 ) {
     my $queue = { };
-    $queue->{queue} = POE::Component::SmokeBox::JobQueue->spawn(
-      'delay' => $self->{delay},
-    );
+    $queue->{queue} = POE::Component::SmokeBox::JobQueue->spawn();
     push @{ $queue->{smokers} }, $smoker;
     push @{ $self->{queues} }, $queue;
     return;
@@ -150,7 +131,7 @@ sub _del_smoker {
 
 sub submit {
   my $self = shift;
-  $poe_kernel->call( $self->{session_id}, 'submit', @_ );
+  $poe_kernel->call( $self->{session_id}, '_submit', @_ );
 }
 
 sub _submit {
@@ -193,13 +174,7 @@ sub _submit {
   return;
 }
 
-sub _reg_ui {
-}
-
-sub _unreg_ui {
-}
-
-"We've Got a Fuzzbox and We're Gonna Use It";
+1;
 
 __END__
 
@@ -233,9 +208,9 @@ POE::Component::SmokeBox - POE enabled CPAN smoke testing with added value.
   
   POE::Session->create(
         package_states => [
-           'main' => [ qw(_start _stop _results) ],
+           'main' => [ qw(_start _stop _results _recent) ],
         ],
-        heap => { perl => $perl, pending => [ @ARGV ] },
+        heap => { perl => $perl, pending => { @ARGV },
   );
   
   $poe_kernel->run();
@@ -260,7 +235,7 @@ POE::Component::SmokeBox - POE enabled CPAN smoke testing with added value.
   }
   
   sub _results {
-    my $results = $_[ARG0];
+    my $result = $_[ARG0];
     print $_, "\n" for map { @{ $_->{log} } } $results->{result}->results();
     undef;
   }
@@ -292,8 +267,7 @@ Creates a new session and returns an object. Takes a number of parameters:
   'options', a hashref of POE session options;
   'multiplicity', set to a true value to enable multiplicity, default is false;
   'smokers', an arrayref of POE::Component::SmokeBox::Smoker objects;
-  'delay', the time in seconds to wait between job runs, default is 0;
-
+  
 =back
 
 =head1 METHODS
@@ -308,8 +282,6 @@ Returns the L<POE::Session> ID of the smokebox component.
 
 Returns true or false depending on whether multiplicity is enabled or not.
 
-NOTE: If you enable multiplicity, you cannot use "delay" as an argument to SmokeBox::Job->new!
-
 =item C<queues>
 
 Returns a list of L<POE::Component::SmokeBox::JobQueue> objects that are currently active in the smokebox.
@@ -322,11 +294,6 @@ Takes one mandatory argument, a L<POE::Component::SmokeBox::Smoker> object to ad
 
 Takes one mandatory argument, a L<POE::Component::SmokeBox::Smoker> object to remove from the smokebox.
 
-=item C<delay>
-
-Sets the delay in seconds between job runs. Useful to "throttle" your smoker :) If called with no arguments, returns
-the current delay. This option will work even if multiplicity is enabled.
-
 =item C<submit>
 
 Submits a job to the smokebox. Takes a number of parameters.
@@ -392,7 +359,6 @@ Each result is a hashref:
   'idle_kill', only present if the job was killed because of excessive idle;
   'excess_kill', only present if the job was killed due to excessive runtime;
   'term_kill', only present if the job was killed due to a poco shutdown event;
-  'cb_kill', only present if the job was killed due to the callback returning false;
 
 =head1 AUTHOR
 
